( cd opt/kde/share/doc/HTML/nn/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/kmail ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/klipper ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/kcontrol ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
